#!/usr/bin/env python

# SPDX-FileCopyrightText: © 2023 Romain Brault <mail@romainbrault.com>
#
# SPDX-License-Identifier: MIT

"""Top-level executable."""

from python_whiteprint.cli import entrypoint


entrypoint.__app__()
